"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var Yup = _interopRequireWildcard(require("yup"));

var _ = _interopRequireDefault(require(".."));

var _Button = _interopRequireDefault(require("../../../atoms/Button"));

describe('Form Component', function () {
  var userFormProps = {
    initialValues: {
      email: '',
      username: '',
      typeOfUser: ''
    },
    debug: false,
    action: '/',
    validationSchema: {
      username: {
        max: [15, 'Max limit reached'],
        required: 'User name Required'
      },
      email: {
        max: [30, 'Max reached'],
        email: 'Invalid email format',
        required: 'Required'
      }
    }
  };
  var SignupSchema = Yup.object().shape({
    username: Yup.string().min(2, 'Too Short!').max(50, 'Too Long!').required('Required')
  });
  test('should render select tag correctly', function () {
    var userFormSelectProps = {
      options: ['Admin', 'Read Only'],
      name: 'typeOfUser',
      label: 'Type of user',
      validateOnBlur: true
    };

    var SelectForm = _react.default.createElement(_.default, userFormProps, _react.default.createElement("div", null, _react.default.createElement(_.default.Select, userFormSelectProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.shallow)(SelectForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input text field', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };

    var InputForm = _react.default.createElement(_.default, userFormProps, _react.default.createElement("div", null, _react.default.createElement(_.default.Input, userFormNameInputProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.shallow)(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render select field', function () {
    var userFormSelectProps = {
      options: ['Admin', 'Read Only'],
      name: 'typeOfUser',
      label: 'Type of user'
    };

    var SelectForm = _react.default.createElement(_.default, userFormProps, _react.default.createElement("div", null, _react.default.createElement(_.default.Select, userFormSelectProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.shallow)(SelectForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input field with yupValidationSchema', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };

    var InputForm = _react.default.createElement(_.default, (0, _extends2.default)({}, userFormProps, {
      yupValidationSchema: SignupSchema
    }), _react.default.createElement("div", null, _react.default.createElement(_.default.Input, userFormNameInputProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.shallow)(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input field with no validation', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };
    var formProps = (0, _extends2.default)({}, userFormProps);
    delete formProps.validationSchema;

    var InputForm = _react.default.createElement(_.default, formProps, _react.default.createElement("div", null, _react.default.createElement(_.default.Input, userFormNameInputProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.shallow)(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('getSchema should return null if no params are passed', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };
    var formProps = (0, _extends2.default)({}, userFormProps);
    delete formProps.validationSchema;

    var InputForm = _react.default.createElement(_.default, formProps, _react.default.createElement("div", null, _react.default.createElement(_.default.Input, userFormNameInputProps)), _react.default.createElement(_Button.default, {
      primary: true,
      type: "submit"
    }, "Submit"));

    var Wrapper = (0, _enzyme.mount)(InputForm);
    expect(Wrapper.instance().getSchema()).toBeNull();
  });
});