"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.PopoverVanilla = exports.default = void 0;

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Popover = _interopRequireDefault(require("./Popover.style"));

/**
 *
 * Popover
 *
 */
var Popover =
/*#__PURE__*/
function (_PureComponent) {
  (0, _inheritsLoose2.default)(Popover, _PureComponent);

  function Popover() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _PureComponent.call.apply(_PureComponent, [this].concat(args)) || this;
    _this.state = {
      showPopover: false
    };
    _this.wrapperRef = (0, _react.createRef)();

    _this.handleClickOutside = function (e) {
      var el = e.target;

      if (_this.wrapperRef && _this.wrapperRef.current && el instanceof Node && !_this.wrapperRef.current.contains(el)) {
        _this.setState({
          showPopover: false
        });
      }
    };

    _this.handleClick = function () {
      _this.setState({
        showPopover: true
      });
    };

    _this.close = function () {
      _this.setState({
        showPopover: false
      });
    };

    return _this;
  }

  var _proto = Popover.prototype;

  /**
   * @componentDidMount
   * Add event listener to handle click outside the wrapper to that popover
   * gets closed and setting showPopover state on the basis of prop if passed
   */
  _proto.componentDidMount = function componentDidMount() {
    document.addEventListener('mousedown', this.handleClickOutside, false);
    var isVisible = this.props.isVisible;

    if (isVisible) {
      this.setState({
        showPopover: isVisible
      });
    }
  }
  /**
   * @componentWillUnmount
   * Remove all event listener on component un-mounting
   */
  ;

  _proto.componentWillUnmount = function componentWillUnmount() {
    document.removeEventListener('mousedown', this.handleClickOutside, false);
  }
  /**
   * @handleClickOutside
   * @param {MouseEvent} e
   * This function handles the outside click from the wrapper
   * to close the popover if open
   */
  ;

  _proto.render = function render() {
    var _this$props = this.props,
        popOverHeader = _this$props.popOverHeader,
        children = _this$props.children,
        hidePopoverCloseBtn = _this$props.hidePopoverCloseBtn,
        className = _this$props.className,
        trigger = _this$props.trigger;
    var showPopover = this.state.showPopover;
    /**
     * Cloning of element needs to be done so that handleClick function can
     * be wrapped around element without wrapping it around another element
     * or creating an extra DOM node
     */

    var element = trigger && _react.default.cloneElement(trigger, {
      onClick: this.handleClick
    });

    return _react.default.createElement("div", {
      role: "presentation",
      ref: this.wrapperRef,
      className: (0, _classnames.default)('popover-wrap', className)
    }, element, showPopover && _react.default.createElement("div", {
      role: "dialog",
      className: "popover"
    }, !hidePopoverCloseBtn && _react.default.createElement("button", {
      className: "popover__close",
      onClick: this.close
    }, "X"), popOverHeader && _react.default.createElement("h3", {
      className: "popover__header"
    }, popOverHeader), _react.default.createElement("div", {
      className: "popover__body"
    }, children)));
  };

  return Popover;
}(_react.PureComponent);

exports.PopoverVanilla = Popover;
Popover.defaultProps = {
  isVisible: false,
  hidePopoverCloseBtn: false
};

var _default = (0, _styledComponents.default)(Popover).withConfig({
  displayName: "Popover",
  componentId: "sc-1xo3w5k-0"
})(["", ";"], _Popover.default);

exports.default = _default;