"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.TabsVanilla = exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Tabs = _interopRequireDefault(require("./Tabs.style"));

var _Tab = _interopRequireDefault(require("./Tab"));

var _TabPanel = _interopRequireDefault(require("./TabPanel"));

var _List = _interopRequireDefault(require("../List"));

var _constants = require("./constants");

/**
 *
 * Tabs
 *
 */
var Tabs =
/*#__PURE__*/
function (_Component) {
  (0, _inheritsLoose2.default)(Tabs, _Component);

  function Tabs() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      selectedIndex: _this.setDefaultActiveTab()
    };

    _this.updateTabChange = function (index) {
      var onTabChange = _this.props.onTabChange;

      _this.setState({
        selectedIndex: index
      });

      if (onTabChange) {
        onTabChange(index);
      }
    };

    _this.tabClick = function (e, index) {
      e.preventDefault();
      var selectedIndex = _this.state.selectedIndex;

      if (selectedIndex === index) {
        return;
      }

      _this.updateTabChange(index);
    };

    _this.tabKeyDown = function (e) {
      if (e.key === _constants.ARROW_LEFT || e.key === _constants.ARROW_RIGHT) {
        e.preventDefault();
      } else {
        return;
      }

      var selectedIndex = _this.state.selectedIndex;
      var tabsContent = _this.props.tabsContent;
      var targetIndex;

      if (e.key === _constants.ARROW_LEFT && selectedIndex > 0) {
        targetIndex = selectedIndex - 1;
      } else if (e.key === _constants.ARROW_RIGHT && selectedIndex < tabsContent.length - 1) {
        targetIndex = selectedIndex + 1;
      } else {
        return;
      }

      _this.updateTabChange(targetIndex);
    };

    return _this;
  }

  var _proto = Tabs.prototype;

  _proto.setDefaultActiveTab = function setDefaultActiveTab() {
    var initialSelectedIndex = this.props.initialSelectedIndex;
    return initialSelectedIndex || 0;
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        className = _this$props.className,
        tabsContent = _this$props.tabsContent,
        tabsId = _this$props.tabsId,
        isVerticalView = _this$props.isVerticalView,
        tabWrapClassName = _this$props.tabWrapClassName,
        panelWrapClassName = _this$props.panelWrapClassName,
        onTabChange = _this$props.onTabChange,
        others = (0, _objectWithoutPropertiesLoose2.default)(_this$props, ["className", "tabsContent", "tabsId", "isVerticalView", "tabWrapClassName", "panelWrapClassName", "onTabChange"]);
    var selectedIndex = this.state.selectedIndex;
    var listOptions = {
      noDefaultView: true,
      inline: !isVerticalView,
      noMargin: true
    };
    return _react.default.createElement("div", (0, _extends2.default)({
      id: tabsId,
      className: (0, _classnames.default)({
        row: isVerticalView
      }, className)
    }, others), _react.default.createElement("div", {
      className: (0, _classnames.default)('tabs-wrap', tabWrapClassName)
    }, _react.default.createElement(_List.default, (0, _extends2.default)({
      role: "tablist"
    }, listOptions), tabsContent && tabsContent.map(function (item, index) {
      return _react.default.createElement(_Tab.default, {
        className: item.tabClassName || '',
        index: index,
        isSelected: index === selectedIndex,
        onClick: _this2.tabClick,
        onKeyDown: _this2.tabKeyDown,
        tabId: "tab-list-item-" + index,
        key: "tab-" + index.toString()
      }, item.tabTitle);
    }))), _react.default.createElement("div", {
      className: (0, _classnames.default)('panels-wrap', panelWrapClassName)
    }, tabsContent && tabsContent.map(function (item, index) {
      return _react.default.createElement(_TabPanel.default, {
        className: item.panelClassName || '',
        isSelected: index === selectedIndex,
        tabId: "tab-list-item-" + index,
        index: index,
        key: "tab-panel-" + index.toString()
      }, item.panelContent);
    })));
  };

  return Tabs;
}(_react.Component);

exports.TabsVanilla = Tabs;
Tabs.defaultProps = {
  className: '',
  tabsId: '',
  inheritedStyles: '',
  initialSelectedIndex: 0,
  isVerticalView: false,
  tabWrapClassName: '',
  panelWrapClassName: ''
};

var _default = (0, _styledComponents.default)(Tabs).withConfig({
  displayName: "Tabs",
  componentId: "sc-1trpncn-0"
})(["", ";"], _Tabs.default);

exports.default = _default;