"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = exports.buildSchema = void 0;

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _react = _interopRequireDefault(require("react"));

var Yup = _interopRequireWildcard(require("yup"));

/**
 * This API is used as an abstraction layer over YUP schema
 * library in order to make form validations more natural
 * Taking an example of a simple user sign in with a username
 * and a password field.
 --------------------------------------------------------------------------
  To create the below Yup Schema equivalent:

  Yup.object().shape({
    username: Yup.string()
      .min(2, 'Too Short!')
      .max(50, 'Too Long!')
      .required('Required'),
    password: Yup.string()
      .required('Required'),
  })

  A plain object (raw Schema) can be sent to the buildSchema function:

  {
    username: {
      min: [2, 'Too short'],
      max: [50, 'Too long']
      required: 'Required'
    },
    password: {
      required: 'Required'
    }
  }
  --------------------------------------------------------------------------

  Yup: https://github.com/jquense/yup
  formik Validations: https://jaredpalmer.com/formik/docs/guides/validation
*/
var getFieldValidation = function getFieldValidation(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'string' : _ref$type,
      args = (0, _objectWithoutPropertiesLoose2.default)(_ref, ["type"]);
  var config = Yup[type]();
  var validationList = Object.keys(args); // TODO: Optimise this function and support nested Yup configs

  validationList.forEach(function (operation) {
    var _config;

    var validatorArgs = typeof args[operation] === 'string' ? Array(args[operation]) : args[operation];
    config = (_config = config)[operation].apply(_config, validatorArgs);
  });
  return config;
};
/**
 * The function builds the schema from a plain object to YUP based config.
 * Consider the mentioned example at the start.
 */


var buildSchema = function buildSchema(rawSchema) {
  var schema = {};

  try {
    // listOfFields will be assigned ['username', 'password']
    var listOfFields = Object.keys(rawSchema);
    listOfFields.forEach(function (fieldName) {
      var field = rawSchema[fieldName];
      schema[fieldName] = getFieldValidation(field);
    });
    return Yup.object().shape(schema);
  } catch (e) {
    return schema;
  }
};

exports.buildSchema = buildSchema;
var _default = buildSchema;
exports.default = _default;