import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { shallow, mount } from 'enzyme';
import * as Yup from 'yup';
import Form from '..';
import Button from '../../../atoms/Button';
describe('Form Component', function () {
  var userFormProps = {
    initialValues: {
      email: '',
      username: '',
      typeOfUser: ''
    },
    debug: false,
    action: '/',
    validationSchema: {
      username: {
        max: [15, 'Max limit reached'],
        required: 'User name Required'
      },
      email: {
        max: [30, 'Max reached'],
        email: 'Invalid email format',
        required: 'Required'
      }
    }
  };
  var SignupSchema = Yup.object().shape({
    username: Yup.string().min(2, 'Too Short!').max(50, 'Too Long!').required('Required')
  });
  test('should render select tag correctly', function () {
    var userFormSelectProps = {
      options: ['Admin', 'Read Only'],
      name: 'typeOfUser',
      label: 'Type of user',
      validateOnBlur: true
    };
    var SelectForm = React.createElement(Form, userFormProps, React.createElement("div", null, React.createElement(Form.Select, userFormSelectProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = shallow(SelectForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input text field', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };
    var InputForm = React.createElement(Form, userFormProps, React.createElement("div", null, React.createElement(Form.Input, userFormNameInputProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = shallow(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render select field', function () {
    var userFormSelectProps = {
      options: ['Admin', 'Read Only'],
      name: 'typeOfUser',
      label: 'Type of user'
    };
    var SelectForm = React.createElement(Form, userFormProps, React.createElement("div", null, React.createElement(Form.Select, userFormSelectProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = shallow(SelectForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input field with yupValidationSchema', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };
    var InputForm = React.createElement(Form, _extends({}, userFormProps, {
      yupValidationSchema: SignupSchema
    }), React.createElement("div", null, React.createElement(Form.Input, userFormNameInputProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = shallow(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('should render input field with no validation', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };

    var formProps = _extends({}, userFormProps);

    delete formProps.validationSchema;
    var InputForm = React.createElement(Form, formProps, React.createElement("div", null, React.createElement(Form.Input, userFormNameInputProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = shallow(InputForm);
    expect(Wrapper).toMatchSnapshot();
  });
  test('getSchema should return null if no params are passed', function () {
    var userFormNameInputProps = {
      name: 'username',
      type: 'text',
      label: 'User Name'
    };

    var formProps = _extends({}, userFormProps);

    delete formProps.validationSchema;
    var InputForm = React.createElement(Form, formProps, React.createElement("div", null, React.createElement(Form.Input, userFormNameInputProps)), React.createElement(Button, {
      primary: true,
      type: "submit"
    }, "Submit"));
    var Wrapper = mount(InputForm);
    expect(Wrapper.instance().getSchema()).toBeNull();
  });
});