import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React from "react";

/**
 *
 * Tabs
 *
 */
import { Component } from 'react';
import styled from 'styled-components';
import classNames from 'classnames';
import styles from './Tabs.style';
import Tab from './Tab';
import TabPanel from './TabPanel';
import List from '../List';
import { ARROW_RIGHT, ARROW_LEFT } from './constants';

var Tabs =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(Tabs, _Component);

  function Tabs() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      selectedIndex: _this.setDefaultActiveTab()
    };

    _this.updateTabChange = function (index) {
      var onTabChange = _this.props.onTabChange;

      _this.setState({
        selectedIndex: index
      });

      if (onTabChange) {
        onTabChange(index);
      }
    };

    _this.tabClick = function (e, index) {
      e.preventDefault();
      var selectedIndex = _this.state.selectedIndex;

      if (selectedIndex === index) {
        return;
      }

      _this.updateTabChange(index);
    };

    _this.tabKeyDown = function (e) {
      if (e.key === ARROW_LEFT || e.key === ARROW_RIGHT) {
        e.preventDefault();
      } else {
        return;
      }

      var selectedIndex = _this.state.selectedIndex;
      var tabsContent = _this.props.tabsContent;
      var targetIndex;

      if (e.key === ARROW_LEFT && selectedIndex > 0) {
        targetIndex = selectedIndex - 1;
      } else if (e.key === ARROW_RIGHT && selectedIndex < tabsContent.length - 1) {
        targetIndex = selectedIndex + 1;
      } else {
        return;
      }

      _this.updateTabChange(targetIndex);
    };

    return _this;
  }

  var _proto = Tabs.prototype;

  _proto.setDefaultActiveTab = function setDefaultActiveTab() {
    var initialSelectedIndex = this.props.initialSelectedIndex;
    return initialSelectedIndex || 0;
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        className = _this$props.className,
        tabsContent = _this$props.tabsContent,
        tabsId = _this$props.tabsId,
        isVerticalView = _this$props.isVerticalView,
        tabWrapClassName = _this$props.tabWrapClassName,
        panelWrapClassName = _this$props.panelWrapClassName,
        onTabChange = _this$props.onTabChange,
        others = _objectWithoutPropertiesLoose(_this$props, ["className", "tabsContent", "tabsId", "isVerticalView", "tabWrapClassName", "panelWrapClassName", "onTabChange"]);

    var selectedIndex = this.state.selectedIndex;
    var listOptions = {
      noDefaultView: true,
      inline: !isVerticalView,
      noMargin: true
    };
    return React.createElement("div", _extends({
      id: tabsId,
      className: classNames({
        row: isVerticalView
      }, className)
    }, others), React.createElement("div", {
      className: classNames('tabs-wrap', tabWrapClassName)
    }, React.createElement(List, _extends({
      role: "tablist"
    }, listOptions), tabsContent && tabsContent.map(function (item, index) {
      return React.createElement(Tab, {
        className: item.tabClassName || '',
        index: index,
        isSelected: index === selectedIndex,
        onClick: _this2.tabClick,
        onKeyDown: _this2.tabKeyDown,
        tabId: "tab-list-item-" + index,
        key: "tab-" + index.toString()
      }, item.tabTitle);
    }))), React.createElement("div", {
      className: classNames('panels-wrap', panelWrapClassName)
    }, tabsContent && tabsContent.map(function (item, index) {
      return React.createElement(TabPanel, {
        className: item.panelClassName || '',
        isSelected: index === selectedIndex,
        tabId: "tab-list-item-" + index,
        index: index,
        key: "tab-panel-" + index.toString()
      }, item.panelContent);
    })));
  };

  return Tabs;
}(Component);

Tabs.defaultProps = {
  className: '',
  tabsId: '',
  inheritedStyles: '',
  initialSelectedIndex: 0,
  isVerticalView: false,
  tabWrapClassName: '',
  panelWrapClassName: ''
};
export default styled(Tabs).withConfig({
  displayName: "Tabs",
  componentId: "sc-1trpncn-0"
})(["", ";"], styles);
export { Tabs as TabsVanilla };